# abs-lib

#### Python library for working with algebraic bayesian networks

## Python library [link](https://pypi.org/project/abslib/)

## Build instructions

- `python3 -m pip install --upgrade pip`
- `python3 -m pip install --upgrade build`
- `python3 -m build`
- `python3 -m pip install --upgrade twine`
- `python3 -m twine upload dist/*`

## Installation script

`pip install -i abslib`
